==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/lb.js <==
OC.L10N.register(
    "core",
    {
    "Turned on maintenance mode" : "Maintenance Modus ass un",
    "Turned off maintenance mode" : "Maintenance Modus ass aus",
    "Updated database" : "Datebank ass geupdate ginn",
    "No image or file provided" : "Kee Bild oder Fichier uginn",
    "Unknown filetype" : "Onbekannten Fichier Typ",
    "Invalid image" : "Ongülteg d'Bild",
    "Sunday" : "Sonndeg",
    "Monday" : "Méindeg",
    "Tuesday" : "Dënschdeg",
    "Wednesday" : "Mëttwoch",
    "Thursday" : "Donneschdeg",
    "Friday" : "Freideg",
    "Saturday" : "Samschdeg",
    "Sun." : "So. ",
    "Mon." : "Méi.",
    "Tue." : "Dë.",
    "Wed." : "Më.",
    "Thu." : "Do.",
    "Fri." : "Fr.",
    "Sat." : "Sa.",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mäerz",
    "April" : "Abrëll",
    "May" : "Mee",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mäe.",
    "Apr." : "Abr.",
    "May." : "Mee",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "Settings" : "Astellungen",
    "Saving..." : "Speicheren...",
    "seconds ago" : "Sekonnen hier",
    "No" : "Nee",
    "Yes" : "Jo",
    "Choose" : "Auswielen",
    "Ok" : "OK",
    "Which files do you want to keep?" : "Weieng Fichieren wëlls de gär behalen?",
    "Cancel" : "Ofbriechen",
    "Continue" : "Weider",
    "(all selected)" : "(all ausgewielt)",
    "({count} selected)" : "({count} ausgewielt)",
    "Shared" : "Gedeelt",
    "Error" : "Feeler",
    "Error while sharing" : "Feeler beim Deelen",
    "Error while unsharing" : "Feeler beim Annuléiere vum Deelen",
    "Error while changing permissions" : "Feeler beim Ännere vun de Rechter",
    "Error setting expiration date" : "Feeler beim Setze vum Verfallsdatum",
    "Set expiration date" : "Verfallsdatum setzen",
    "Expiration date" : "Verfallsdatum",
    "Sending ..." : "Gëtt geschéckt...",
    "Email sent" : "Email geschéckt",
    "Resharing is not allowed" : "Weiderdeelen ass net erlaabt",
    "Share link" : "Link deelen",
    "Password protect" : "Passwuertgeschützt",
    "Password" : "Passwuert",
    "Email link to person" : "Link enger Persoun mailen",
    "Send" : "Schécken",
    "Shared with you and the group {group} by {owner}" : "Gedeelt mat dir an der Grupp {group} vum {owner}",
    "Shared with you by {owner}" : "Gedeelt mat dir vum {owner}",
    "Shared in {item} with {user}" : "Gedeelt an {item} mat {user}",
    "group" : "Grupp",
    "notify by email" : "via e-mail Bescheed ginn",
    "Unshare" : "Net méi deelen",
    "can share" : "kann deelen",
    "can edit" : "kann änneren",
    "create" : "erstellen",
    "delete" : "läschen",
    "access control" : "Zougrëffskontroll",
    "Share" : "Deelen",
    "Warning" : "Warnung",
    "The object type is not specified." : "Den Typ vum Object ass net uginn.",
    "Enter new" : "Gëff nei an",
    "Delete" : "Läschen",
    "Add" : "Dobäisetzen",
    "Edit tags" : "Tags editéieren",
    "The update was successful. Redirecting you to ownCloud now." : "Den Update war erfollegräich.  Du gëss elo bei d'ownCloud ëmgeleet.",
    "%s password reset" : "%s Passwuert ass nei gesat",
    "Use the following link to reset your password: {link}" : "Benotz folgende Link fir däi Passwuert zréckzesetzen: {link}",
    "New password" : "Neit Passwuert",
    "Reset password" : "Passwuert zréck setzen",
    "Personal" : "Perséinlech",
    "Users" : "Benotzer",
    "Apps" : "Applikatiounen",
    "Admin" : "Admin",
    "Help" : "Hëllef",
    "Error tagging" : "Fehler beim Taggen",
    "Error untagging" : "Fehler beim Tag läschen",
    "Access forbidden" : "Zougrëff net erlaabt",
    "Cheers!" : "Prost!",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Däin Daten-Dossier an deng Fichieren si wahrscheinlech iwwert den Internet accessibel well den .htaccess-Fichier net funktionnéiert.",
    "Create an <strong>admin account</strong>" : "En <strong>Admin-Account</strong> uleeën",
    "Username" : "Benotzernumm",
    "Data folder" : "Daten-Dossier",
    "Configure the database" : "D'Datebank konfiguréieren",
    "Database user" : "Datebank-Benotzer",
    "Database password" : "Datebank-Passwuert",
    "Database name" : "Datebank Numm",
    "Database tablespace" : "Tabelle-Plaz vun der Datebank",
    "Database host" : "Datebank-Server",
    "Finish setup" : "Installatioun ofschléissen",
    "Finishing …" : "Schléissen of ...",
    "Log out" : "Ofmellen",
    "Search" : "Sichen",
    "Log in" : "Umellen",
    "remember" : "verhalen",
    "Alternative Logins" : "Alternativ Umeldungen",
    "Thank you for your patience." : "Merci fir deng Gedold."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/lb.js <==
OC.L10N.register(
    "core",
    {
    "Turned on maintenance mode" : "Maintenance Modus ass un",
    "Turned off maintenance mode" : "Maintenance Modus ass aus",
    "Updated database" : "Datebank ass geupdate ginn",
    "No image or file provided" : "Kee Bild oder Fichier uginn",
    "Unknown filetype" : "Onbekannten Fichier Typ",
    "Invalid image" : "Ongülteg d'Bild",
    "%s password reset" : "%s Passwuert ass nei gesat",
    "Sunday" : "Sonndeg",
    "Monday" : "Méindeg",
    "Tuesday" : "Dënschdeg",
    "Wednesday" : "Mëttwoch",
    "Thursday" : "Donneschdeg",
    "Friday" : "Freideg",
    "Saturday" : "Samschdeg",
    "Sun." : "So. ",
    "Mon." : "Méi.",
    "Tue." : "Dë.",
    "Wed." : "Më.",
    "Thu." : "Do.",
    "Fri." : "Fr.",
    "Sat." : "Sa.",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mäerz",
    "April" : "Abrëll",
    "May" : "Mee",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mäe.",
    "Apr." : "Abr.",
    "May." : "Mee",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "Settings" : "Astellungen",
    "Saving..." : "Speicheren...",
    "seconds ago" : "Sekonnen hier",
    "No" : "Nee",
    "Yes" : "Jo",
    "Choose" : "Auswielen",
    "Ok" : "OK",
    "Which files do you want to keep?" : "Weieng Fichieren wëlls de gär behalen?",
    "Cancel" : "Ofbriechen",
    "Continue" : "Weider",
    "(all selected)" : "(all ausgewielt)",
    "({count} selected)" : "({count} ausgewielt)",
    "Shared" : "Gedeelt",
    "Error" : "Feeler",
    "Error while sharing" : "Feeler beim Deelen",
    "Error while unsharing" : "Feeler beim Annuléiere vum Deelen",
    "Error setting expiration date" : "Feeler beim Setze vum Verfallsdatum",
    "Set expiration date" : "Verfallsdatum setzen",
    "Expiration date" : "Verfallsdatum",
    "Sending ..." : "Gëtt geschéckt...",
    "Email sent" : "Email geschéckt",
    "Resharing is not allowed" : "Weiderdeelen ass net erlaabt",
    "Share link" : "Link deelen",
    "Password protect" : "Passwuertgeschützt",
    "Password" : "Passwuert",
    "Email link to person" : "Link enger Persoun mailen",
    "Send" : "Schécken",
    "Shared with you and the group {group} by {owner}" : "Gedeelt mat dir an der Grupp {group} vum {owner}",
    "Shared with you by {owner}" : "Gedeelt mat dir vum {owner}",
    "group" : "Grupp",
    "notify by email" : "via e-mail Bescheed ginn",
    "Unshare" : "Net méi deelen",
    "can share" : "kann deelen",
    "can edit" : "kann änneren",
    "create" : "erstellen",
    "delete" : "läschen",
    "access control" : "Zougrëffskontroll",
    "Share" : "Deelen",
    "Warning" : "Warnung",
    "Delete" : "Läschen",
    "Rename" : "Ëmbenennen",
    "The object type is not specified." : "Den Typ vum Object ass net uginn.",
    "Enter new" : "Gëff nei an",
    "Add" : "Dobäisetzen",
    "Edit tags" : "Tags editéieren",
    "The update was successful. Redirecting you to ownCloud now." : "Den Update war erfollegräich.  Du gëss elo bei d'ownCloud ëmgeleet.",
    "Personal" : "Perséinlech",
    "Users" : "Benotzer",
    "Apps" : "Applikatiounen",
    "Admin" : "Admin",
    "Help" : "Hëllef",
    "Error tagging" : "Fehler beim Taggen",
    "Error untagging" : "Fehler beim Tag läschen",
    "Access forbidden" : "Zougrëff net erlaabt",
    "Cheers!" : "Prost!",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Däin Daten-Dossier an deng Fichieren si wahrscheinlech iwwert den Internet accessibel well den .htaccess-Fichier net funktionnéiert.",
    "Create an <strong>admin account</strong>" : "En <strong>Admin-Account</strong> uleeën",
    "Username" : "Benotzernumm",
    "Data folder" : "Daten-Dossier",
    "Configure the database" : "D'Datebank konfiguréieren",
    "Database user" : "Datebank-Benotzer",
    "Database password" : "Datebank-Passwuert",
    "Database name" : "Datebank Numm",
    "Database tablespace" : "Tabelle-Plaz vun der Datebank",
    "Database host" : "Datebank-Server",
    "Finish setup" : "Installatioun ofschléissen",
    "Finishing …" : "Schléissen of ...",
    "Log out" : "Ofmellen",
    "Search" : "Sichen",
    "Log in" : "Umellen",
    "Alternative Logins" : "Alternativ Umeldungen",
    "Use the following link to reset your password: {link}" : "Benotz folgende Link fir däi Passwuert zréckzesetzen: {link}",
    "New password" : "Neit Passwuert",
    "Reset password" : "Passwuert zréck setzen",
    "Thank you for your patience." : "Merci fir deng Gedold."
},
"nplurals=2; plural=(n != 1);");
